Package org.hyperledger.besu.plugin.data
Interface LogWithMetadata
-
public interface LogWithMetadataA Log entry from a transaction execution.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description HashgetBlockHash()longgetBlockNumber()UnformattedDatagetData()The data, of possibly unlimited length, for this log entry.AddressgetLogger()The address of the contract writing this log message.intgetLogIndex()java.util.List<? extends UnformattedData>getTopics()The list of 32 byte log topics, possibly empty.HashgetTransactionHash()intgetTransactionIndex()booleanisRemoved()
-
-
-
Method Detail
-
getLogger
Address getLogger()
The address of the contract writing this log message.- Returns:
- The loggers address.
-
getTopics
java.util.List<? extends UnformattedData> getTopics()
The list of 32 byte log topics, possibly empty.- Returns:
- The list, possibly zero length, of log topics.
-
getData
UnformattedData getData()
The data, of possibly unlimited length, for this log entry.- Returns:
- The log data.
-
getLogIndex
int getLogIndex()
-
getBlockNumber
long getBlockNumber()
-
getBlockHash
Hash getBlockHash()
-
getTransactionHash
Hash getTransactionHash()
-
getTransactionIndex
int getTransactionIndex()
-
isRemoved
boolean isRemoved()
-
-