Interface StorageService
-
public interface StorageServiceThis service allows plugins to register as an available storage engine.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description java.util.List<SegmentIdentifier>getAllSegmentIdentifiers()Retrieves the identifiers for the isolation segments that could be requested during operation.java.util.Optional<KeyValueStorageFactory>getByName(java.lang.String name)Retrieves a registered factory corresponding to the supplied factory namevoidregisterKeyValueStorage(KeyValueStorageFactory factory)Registers a factory as available for creating key-value storage instances.
-
-
-
Method Detail
-
registerKeyValueStorage
void registerKeyValueStorage(KeyValueStorageFactory factory)
Registers a factory as available for creating key-value storage instances.- Parameters:
factory- creates instances providing key-value storage.
-
getAllSegmentIdentifiers
java.util.List<SegmentIdentifier> getAllSegmentIdentifiers()
Retrieves the identifiers for the isolation segments that could be requested during operation.- Returns:
- full set of possible segments required from the storage service.
-
getByName
java.util.Optional<KeyValueStorageFactory> getByName(java.lang.String name)
Retrieves a registered factory corresponding to the supplied factory name- Parameters:
name- The name of the factory to retrieve- Returns:
- an optional containing the instance of the registered factory, or empty if the factory hasn't been registered.
-
-