Interface PoaQueryService
-
- All Known Subinterfaces:
IbftQueryService
public interface PoaQueryServiceProvides methods to query the status of a Proof of Authority (PoA) network.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description AddressgetLocalSignerAddress()Retrieves the signerAddressof the local node.AddressgetProposerOfBlock(BlockHeader header)Retrieves theAddressfor the proposer of a block on the canonical chain.java.util.Collection<Address>getValidatorsForLatestBlock()Retrieves the validators specified in the latest block from the canonical chain.
-
-
-
Method Detail
-
getValidatorsForLatestBlock
java.util.Collection<Address> getValidatorsForLatestBlock()
Retrieves the validators specified in the latest block from the canonical chain.- Returns:
- Addresses of all validators in the latest canonical block.
-
getProposerOfBlock
Address getProposerOfBlock(BlockHeader header)
Retrieves theAddressfor the proposer of a block on the canonical chain.- Parameters:
header- TheBlockHeaderfor which the proposer will be found.- Returns:
- The identity of the proposer for the given block.
-
getLocalSignerAddress
Address getLocalSignerAddress()
Retrieves the signerAddressof the local node. This is the address added to theBlockHeaderto identify that a specific node was a validator during block creation.- Returns:
- The signer
Addressof the local node.
-
-